<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use App\Helpers\ChineseNameConverter;


class Artist extends Model
{
    /** @use HasFactory<\Database\Factories\ArtistFactory> */
    use HasFactory;

    protected $fillable = [
        'category_id',
        'name',
        'simplified',
        'phonetic_abbr',
        'pinyin_abbr',
    ];

    public function category()
    {
        return $this->belongsTo(ArtistCategory::class, 'category_id', 'id');
    }

    public function songs() {
        return $this->belongsToMany(Song::class);
    }
    
    protected static function booted()
    {
        // 無論是 creating 或 updating，都執行這段共用的邏輯
        static::saving(function ($artist) {
            $simplified=ChineseNameConverter::convertToSimplified($artist->name);// 繁體轉簡體
            $artist->simplified =  $simplified;
            $artist->phonetic_abbr = ChineseNameConverter::getKTVZhuyinAbbr($simplified);// 注音符號
            $artist->pinyin_abbr=ChineseNameConverter::getKTVPinyinAbbr($simplified);// 拼音首字母
        });
    }

}
